/*
 *    NzdlQueryHit.java
 *    Copyright (C) 2001 New Zealand Digital Library Project
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

//the package we're in
package org.nzdl.gsdl.service;

import java.util.Map;
import java.util.Set;
import java.util.Collection;

/**
 * Holds a single result from a query. NzdlQueryHit is used by
 * {@link NzdlResponse NzdlResponse} and
 * {@link NzdlResultSet NzdlResultSet}
 *
 * @author Stuart Yeates  (say1@cs.waikato.ac.nz)
 * @author Aziz Mahoui    (amahoui@yahoo.com)
 * @author Gordon Paynter (paynter@cs.waikato.ac.nz)
 * @author Brett Sheeran (bsheeran@xtra.co.nz) (comments)
 */
public class NzdlQueryHit extends java.lang.Object {

  private String m_docID = null;
  private int    m_resultNum = -1;   // I don't actually know what it means !!!
  private int    m_ranking = -1;
  private int    m_numTermsMatched = -1;
  private int    m_numPhrasesMatched = -1;
  private int [] m_docFreqs = null; // I don't actually know what it means !!!
  /*
   * The key in the map will be the metaData Tag
   * The value for the key will be a Set of strings
   * Ex: key = "Author", value = {A. Mahoui, S. Franks}
   */
  private Map m_metaData = null;

  /**
   * Sets the document ID.
   * @param docID a string representaion of the document ID.
   */
  public void setDocumentID( String _docID ) {
    m_docID = _docID;
  }

  /**
   * Sets the ranking.
   * @param the ranking an integer representaion of the the hit's ranking.
   */
  public void setRanking( int _ranking ) {
    m_ranking = _ranking;
  }

  /**
   * Sets the result number.
   * @param resultNum is the integer representation of the result number.
   */
  public void setResultNumber( int _resultNum ) {
    m_resultNum = _resultNum;
  }

  /**
   * Sets the number of terms matched.
   * @param numTermsMatched the number of terms matched.
   */
  public void setNumOfTermsMatched( int _numTermsMatched ) {
    m_numTermsMatched = _numTermsMatched;
  }

  /**
   * Sets the number of phrases matched.
   * @param numPhrasesMatched the number of phrases matched.
   */
  public void setNumOfPhrasesMatched( int _numPhrasesMatched ) {
    m_numPhrasesMatched = _numPhrasesMatched;
  }

  /**
   * Sets the metedata
   * @param metaData the key in the map will be the metaData tag.
   * The value for the key will be a Set of strings.
   * For example: key = "Author", value = {A. Mahoui, S. Franks}
   */
  public void setMetaData( Map _metaData ) {
    m_metaData = _metaData;
  }

  /**
   * Gets the document ID of the query hit.
   * @return document ID in string form.
   */
  public String getDocumentID() {
    return m_docID;
  }

  /**
   * Gets the ranking of the query hit.
   * @return integer representing the hits ranking.
   */
  public int getRanking() {
    return m_ranking;
  }

  /**
   * Gets the result number of the query hit.
   * @return integer representing the result number.
   */
  public int getResultNumber() {
    return m_resultNum;
  }

  /**
   * Gets the number of terms matched in the hit. A term is an individual word
   * in a query phrase.
   * @return integer representing the number of terms matched.
   */
  public int getNumOfTermsMatched() {
    return m_numTermsMatched;
  }

  /**
   * Gets the number of phrases matched in the hit.
   * @return integer representing the number of phrases matched.
   */
  public int getNumOfPhrasesMatched() {
    return m_numPhrasesMatched;
  }

  /**
   * Gets the metaData of the hit document.
   * @return a map of the metadata. For example: key = "Author", value =
   * {A. Mahoui, S. Franks}
   */
  public Map getMetaData() {
    return m_metaData;
  }

  /**
  * Gets a set of values for a metatag.
  * @param a metatag, such as author.
  * @return A set of string values for that metatag.
  */
  public Set getMetaDataValues( String _metaTag ) {
    return (Set) m_metaData.get( _metaTag );
  }

  /** Gets the metatags for a hit.
   * @return a set of key (String) objects such as Author, Title etc.
   */
  public Set getMetaDataTags() {
    return m_metaData.keySet();
  }

  /**
   * Gets a collection of metatag values for a hit.
   * @return a collection of metatag values.
   */
  public Collection getMetaDataValues() {
    return m_metaData.values();
  }

}
